@@ -12,6 +12,7 @@ from typing import (
     List,
     Mapping,
     Optional,
+    Protocol,
     Tuple,
     TypeVar,
     Union,
@@ -27,7 +28,6 @@ from click.shell_completion import (
     ZshComplete,
     add_completion_class,
 )
-from typing_extensions import Protocol
 from yarl import URL
 
 from apolo_sdk import (
@@ -49,26 +49,22 @@ from .parse_utils import (
 )
 from .root import Root
 
-# NOTE: these job name defaults are taken from `platform_api` file `validators.py`
 JOB_NAME_MIN_LENGTH = 3
 JOB_NAME_MAX_LENGTH = 40
-JOB_NAME_PATTERN = "^[a-z](?:-?[a-z0-9])*$"
+JOB_NAME_PATTERN = "^[a-z][a-z0-9]*(?:-[a-z0-9]+)*$"
 JOB_NAME_REGEX = re.compile(JOB_NAME_PATTERN)
 JOB_LIMIT_ENV = "NEURO_CLI_JOB_AUTOCOMPLETE_LIMIT"
 
 
-# NOTE: these disk name validation are taken from `platform_disk_api` file `schema.py`
 DISK_NAME_MIN_LENGTH = 3
 DISK_NAME_MAX_LENGTH = 40
-DISK_NAME_PATTERN = "^[a-z](?:-?[a-z0-9])*$"
+DISK_NAME_PATTERN = "^[a-z][a-z0-9]*(?:-[a-z0-9]+)*$"
 DISK_NAME_REGEX = re.compile(JOB_NAME_PATTERN)
 
 
-# NOTE: these bucket name validation are taken from
-# `platform_buckets_api` file `schema.py`
 BUCKET_NAME_MIN_LENGTH = 3
 BUCKET_NAME_MAX_LENGTH = 40
-BUCKET_NAME_PATTERN = "^[a-z](?:-?[a-z0-9_-])*$"
+BUCKET_NAME_PATTERN = "^[a-z][a-z0-9_]*(?:-+[a-z0-9_]+)*$"
 BUCKET_NAME_REGEX = re.compile(BUCKET_NAME_PATTERN)
 
 
@@ -474,7 +470,6 @@ CLUSTER_ALLOW_UNKNOWN = ClusterType(allow_unknown=True)
 
 class OrgType(AsyncType[str]):
     name = "org"
-    NO_ORG_STR = "NO_ORG"
 
     def __init__(self, allow_unknown: bool = False):
         self._allow_unknown = allow_unknown
@@ -489,11 +484,11 @@ class OrgType(AsyncType[str]):
         if self._allow_unknown:
             return value
         client = await root.init_client()
-        org_name = value if value != self.NO_ORG_STR else None
-        if org_name not in client.config.clusters[client.config.cluster_name].orgs:
+        org_name = value
+        if org_name not in client.config.available_orgs:
+            avail = ", ".join(client.config.available_orgs)
             raise click.BadParameter(
-                f"Org {value} is not valid, "
-                "run 'apolo config get-clusters' to get a list of available orgs",
+                f"Org {value} is not valid, " f"available orgs are {{{avail}}}",
                 ctx,
                 param,
             )
@@ -505,7 +500,7 @@ class OrgType(AsyncType[str]):
         # async context manager is used to prevent a message about
         # unclosed session
         async with await root.init_client() as client:
-            org_names = [org or self.NO_ORG_STR for org in client.config.cluster_orgs]
+            org_names = client.config.available_orgs
             return [
                 CompletionItem(org_name)
                 for org_name in org_names
@@ -762,11 +757,9 @@ class URLCompleter(abc.ABC):
 class PathURLCompleter(URLCompleter, abc.ABC):
     class DirEntry(Protocol):
         @property
-        def name(self) -> str:
-            ...
+        def name(self) -> str: ...
 
-        def is_dir(self) -> bool:
-            ...
+        def is_dir(self) -> bool: ...
 
     def __init__(
         self,
@@ -789,10 +782,15 @@ class PathURLCompleter(URLCompleter, abc.ABC):
     ) -> CompletionItem:
         if is_dir:
             name += "/"
+        ppath = parent.path
+        prefix = str(parent)
+        if (parent.host and ppath == "/") or (ppath and not ppath.endswith("/")):
+            if prefix and not prefix.endswith("/"):
+                prefix += "/"
         return CompletionItem(
             name,
             type="uri",
-            prefix=str(parent / ""),
+            prefix=prefix,
         )
 
     @abc.abstractmethod
@@ -883,8 +881,8 @@ class BlobPathURLCompleter(PathURLCompleter):
         if not self._is_bucket_uri_complete(full_uri, root, incomplete):
             prefix = uri.parent
             full_prefix = full_uri.parent if uri.path else full_uri
-            full_prefix_str = str(full_prefix / "")
-            full_uri_str = str(full_uri if uri.path else full_uri / "")
+            full_prefix_str = str(full_prefix)
+            full_uri_str = str(full_uri) if uri.path else str(full_uri) + "/"
             completions = set()
             async with root.client.buckets.list(cluster_name=full_uri.host) as it:
                 async for bucket in it:
@@ -896,6 +894,8 @@ class BlobPathURLCompleter(PathURLCompleter):
                         if not bucket_uri_str.startswith(full_uri_str):
                             continue
                         path_parts = bucket_uri_str[len(full_prefix_str) :].split("/")
+                        if path_parts and not path_parts[0]:
+                            del path_parts[0]
                         if len(path_parts) == 0:
                             continue
                         name = path_parts[0]
@@ -907,7 +907,7 @@ class BlobPathURLCompleter(PathURLCompleter):
             # benefit from prefix search in list_blobs().
             if incomplete.endswith("/"):
                 prefix = uri
-                full_uri = full_uri / ""
+                full_uri = URL(str(full_uri) + "/")
                 skip_uri_len = len(full_uri.parts)
             else:
                 prefix = uri.parent
