@@ -5,7 +5,7 @@ from random import random
 from typing import Optional
 
 DATETIME_FORMAT = "%Y-%m-%d_%H-%M-%S"
-LOGS_DIR = Path("~/.neuro/logs").expanduser()
+LOGS_DIR = Path("~/.apolo/logs").expanduser()
 FILE_FORMAT_PREFIX = "apolo-run-"
 LOGS_ROTATION_DELAY = timedelta(days=3)
 
