@@ -7,18 +7,14 @@ from rich.console import RenderableType
 from rich.rule import Rule
 from rich.styled import Styled
 from rich.table import Column, Table
-from rich.text import Text
 
 from apolo_sdk import (
-    _AWSStorageOptions,
-    _AzureStorageOptions,
     _CloudProviderOptions,
     _CloudProviderType,
     _Cluster,
     _ClusterUser,
     _ClusterUserWithInfo,
     _ConfigCluster,
-    _GoogleStorageOptions,
     _NodePool,
     _NodePoolOptions,
     _Org,
@@ -30,7 +26,7 @@ from apolo_sdk import (
 )
 
 from apolo_cli.formatters.config import format_quota_details
-from apolo_cli.formatters.utils import format_datetime_iso
+from apolo_cli.formatters.utils import format_datetime_iso, format_multiple_gpus
 from apolo_cli.utils import format_size
 
 
@@ -39,14 +35,12 @@ class ClusterUserWithInfoFormatter:
         self, clusters_users: Iterable[_ClusterUserWithInfo]
     ) -> RenderableType:
         table = Table(box=box.MINIMAL_HEAVY_HEAD)
-        table.add_column("Name", style="bold")
+        table.add_column("Name", style="bold", max_width=None, no_wrap=True)
         table.add_column("Org")
         table.add_column("Role")
         table.add_column("Email")
         table.add_column("Full name")
         table.add_column("Registered")
-        table.add_column("Credits", max_width=10, overflow="fold")
-        table.add_column("Spent credits", max_width=14, overflow="fold")
         table.add_column("Max jobs", max_width=10, overflow="fold")
         rows = []
 
@@ -59,8 +53,6 @@ class ClusterUserWithInfoFormatter:
                     user.user_info.email,
                     user.user_info.full_name,
                     format_datetime_iso(user.user_info.created_at),
-                    format_quota_details(user.balance.credits),
-                    format_quota_details(user.balance.spent_credits),
                     format_quota_details(user.quota.total_running_jobs),
                 )
             )
@@ -95,6 +87,8 @@ class OrgUserFormatter:
         table.add_column("Email")
         table.add_column("Full name")
         table.add_column("Registered")
+        table.add_column("Credits", max_width=10, overflow="fold")
+        table.add_column("Spent credits", max_width=14, overflow="fold")
         rows = []
 
         for user in org_users:
@@ -105,6 +99,8 @@ class OrgUserFormatter:
                     user.user_info.email,
                     user.user_info.full_name,
                     format_datetime_iso(user.user_info.created_at),
+                    format_quota_details(user.balance.credits),
+                    format_quota_details(user.balance.spent_credits),
                 )
             )
         rows.sort(key=operator.itemgetter(0))
@@ -258,7 +254,7 @@ def _format_node_pools(
         box=box.SIMPLE_HEAVY,
         show_edge=True,
     )
-    table.add_column("Name", style="bold", justify="left")
+    table.add_column("Name", style="bold", justify="left", max_width=None, no_wrap=True)
     if type != _CloudProviderType.ON_PREM:
         table.add_column("Machine", style="bold", justify="left")
     table.add_column("CPU", justify="right")
@@ -289,7 +285,7 @@ def _format_node_pools(
             row.append(format_size(node_pool.disk_size))
         if has_preemptible:
             row.append("√" if node_pool.is_preemptible else "×")
-        row.append(_gpu(node_pool))
+        row.append(format_multiple_gpus(node_pool))
         if is_scalable:
             row.append(str(node_pool.min_size))
         row.append(str(node_pool.max_size))
@@ -346,10 +342,18 @@ def _has_idle(node_pools: Iterable[_NodePool]) -> bool:
     return False
 
 
-def _gpu(node_pool: _NodePool) -> str:
-    if node_pool.gpu:
-        return f"{node_pool.gpu} x {node_pool.gpu_model}"
-    return ""
+class OrgFormatter:
+    def __call__(self, org: _Org) -> RenderableType:
+        table = Table(box=None, show_header=False, show_edge=False)
+        table.add_column()
+        table.add_column(style="bold")
+        table.add_row("Name", org.name)
+        table.add_row("Credits", format_quota_details(org.balance.credits))
+        table.add_row("Spent credits", format_quota_details(org.balance.spent_credits))
+        table.add_row(
+            "User default credits", format_quota_details(org.user_default_credits)
+        )
+        return table
 
 
 class OrgsFormatter:
@@ -365,7 +369,6 @@ class CloudProviderOptionsFormatter:
     def __call__(self, options: _CloudProviderOptions) -> RenderableType:
         out: list[RenderableType] = []
         table = Table(
-            Column("Id"),
             Column("Machine"),
             Column("CPU"),
             Column("CPU Avail"),
@@ -380,7 +383,6 @@ class CloudProviderOptionsFormatter:
         )
         for np in options.node_pools:
             table.add_row(
-                np.id,
                 np.machine_type,
                 str(np.cpu),
                 str(np.available_cpu),
@@ -389,79 +391,13 @@ class CloudProviderOptionsFormatter:
                 self._gpu(np),
             )
         out.append(table)
-        out.append(Text())
-        if options.type == _CloudProviderType.AWS:
-            out.append(self._format_aws_storages(options.storages))  # type: ignore
-        elif options.type == _CloudProviderType.GCP:
-            out.append(self._format_google_storages(options.storages))  # type: ignore
-        elif options.type == _CloudProviderType.AZURE:
-            out.append(self._format_azure_storages(options.storages))  # type: ignore
-        else:
-            out.pop()
         return RichGroup(*out)
 
     def _gpu(self, node_pool: _NodePoolOptions) -> str:
-        if node_pool.gpu:
-            return f"{node_pool.gpu} x {node_pool.gpu_model}"
+        if node_pool.nvidia_gpu:
+            return f"{node_pool.nvidia_gpu} x {node_pool.nvidia_gpu_model}"
         return ""
 
-    def _format_aws_storages(self, storages: Iterable[_AWSStorageOptions]) -> Table:
-        table = Table(
-            Column("Id"),
-            Column("Performance"),
-            Column("Throughput"),
-            box=box.SIMPLE_HEAVY,
-            show_edge=False,
-            title="Available storages:",
-            title_justify="left",
-            title_style="bold italic",
-        )
-        for s in storages:
-            table.add_row(s.id, s.performance_mode, s.throughput_mode)
-        return table
-
-    def _format_google_storages(
-        self, storages: Iterable[_GoogleStorageOptions]
-    ) -> Table:
-        table = Table(
-            Column("Id"),
-            Column("Tier"),
-            Column("Capacity"),
-            box=box.SIMPLE_HEAVY,
-            show_edge=False,
-            title="Available storages:",
-            title_justify="left",
-            title_style="bold italic",
-        )
-        for s in storages:
-            min_capacity = format_size(s.min_capacity)
-            max_capacity = format_size(s.max_capacity)
-            table.add_row(s.id, s.tier.capitalize(), f"{min_capacity} - {max_capacity}")
-        return table
-
-    def _format_azure_storages(self, storages: Iterable[_AzureStorageOptions]) -> Table:
-        table = Table(
-            Column("Id"),
-            Column("Tier"),
-            Column("Replication"),
-            Column("Capacity"),
-            box=box.SIMPLE_HEAVY,
-            show_edge=False,
-            title="Available storages:",
-            title_justify="left",
-            title_style="bold italic",
-        )
-        for s in storages:
-            min_capacity = format_size(s.min_file_share_size)
-            max_capacity = format_size(s.max_file_share_size)
-            table.add_row(
-                s.id,
-                s.tier.capitalize(),
-                s.replication_type,
-                f"{min_capacity} - {max_capacity}",
-            )
-        return table
-
 
 class ProjectsFormatter:
     def __call__(self, projects: Iterable[_Project]) -> RenderableType:
