@@ -6,7 +6,6 @@ from unittest import mock
 from apolo_sdk import (
     Preset,
     _Admin,
-    _AWSStorageOptions,
     _Balance,
     _CloudProviderOptions,
     _CloudProviderType,
@@ -14,9 +13,10 @@ from apolo_sdk import (
     _ClusterUser,
     _ClusterUserRoleType,
     _ClusterUserWithInfo,
-    _EFSPerformanceMode,
-    _EFSThroughputMode,
     _NodePoolOptions,
+    _OrgUserRoleType,
+    _OrgUserWithInfo,
+    _PatchNodePoolSizeRequest,
     _Quota,
     _ResourcePreset,
     _TPUPreset,
@@ -37,7 +37,6 @@ def mock_create_cluster_user() -> Iterator[None]:
             cluster_name: str,
             user_name: str,
             role: _ClusterUserRoleType,
-            balance: _Balance,
             quota: _Quota,
             org_name: Optional[str] = None,
         ) -> _ClusterUserWithInfo:
@@ -48,7 +47,7 @@ def mock_create_cluster_user() -> Iterator[None]:
                 org_name=org_name,
                 role=_ClusterUserRoleType.MANAGER,
                 quota=quota,
-                balance=balance,
+                balance=_Balance(),
                 user_info=_UserInfo(
                     email="some@email.com",
                     created_at=None,
@@ -61,13 +60,39 @@ def mock_create_cluster_user() -> Iterator[None]:
         yield
 
 
+@contextmanager
+def mock_create_org_user() -> Iterator[None]:
+    with mock.patch.object(_Admin, "create_org_user") as mocked:
+
+        async def create_org_user(
+            org_name: str,
+            user_name: str,
+            role: _OrgUserRoleType,
+            balance: _Balance,
+        ) -> _OrgUserWithInfo:
+            return _OrgUserWithInfo(
+                user_name=user_name,
+                org_name=org_name,
+                role=role,
+                balance=balance,
+                user_info=_UserInfo(
+                    email="some@email.com",
+                    created_at=None,
+                    first_name=None,
+                    last_name=None,
+                ),
+            )
+
+        mocked.side_effect = create_org_user
+        yield
+
+
 def test_add_cluster_user_print_result(run_cli: _RunCli) -> None:
     with mock_create_cluster_user():
         capture = run_cli(["admin", "add-cluster-user", "default", "ivan", "admin"])
     assert not capture.err
     assert "Added ivan to cluster default as manager" in capture.out
     assert "Jobs: unlimited" in capture.out
-    assert "Credits: unlimited" in capture.out
     assert capture.code == 0
 
     # Same with quiet mode
@@ -80,40 +105,6 @@ def test_add_cluster_user_print_result(run_cli: _RunCli) -> None:
     assert capture.code == 0
 
 
-def test_add_cluster_user_with_credits(run_cli: _RunCli) -> None:
-    for value in ("1234.5", "0", "-1234.5", "unlimited"):
-        with mock_create_cluster_user():
-            capture = run_cli(
-                [
-                    "admin",
-                    "add-cluster-user",
-                    "default",
-                    "ivan",
-                    "admin",
-                    "--credits",
-                    value,
-                ]
-            )
-        assert not capture.err
-        assert capture.code == 0
-
-    for value in ("spam", "inf", "nan", "infinity", "Infinity"):
-        with mock_create_cluster_user():
-            capture = run_cli(
-                [
-                    "admin",
-                    "add-cluster-user",
-                    "default",
-                    "ivan",
-                    "admin",
-                    "--credits",
-                    value,
-                ]
-            )
-        assert f"{value} is not valid decimal number" in capture.err, capture
-        assert capture.code == 2
-
-
 def test_add_cluster_user_with_jobs(run_cli: _RunCli) -> None:
     for value in ("100", "0", "unlimited"):
         with mock_create_cluster_user():
@@ -208,21 +199,18 @@ def test_update_cluster_user(run_cli: _RunCli) -> None:
 
 
 def test_set_user_credits(run_cli: _RunCli) -> None:
-    with mock.patch.object(_Admin, "update_cluster_user_balance") as mocked:
+    with mock.patch.object(_Admin, "update_org_user_balance") as mocked:
 
-        async def update_cluster_user_balance(
-            cluster_name: str,
+        async def update_org_user_balance(
+            org_name: str,
             user_name: str,
             credits: Optional[Decimal],
-            org_name: Optional[str] = None,
-        ) -> _ClusterUserWithInfo:
-            return _ClusterUserWithInfo(
-                cluster_name=cluster_name,
-                user_name=user_name,
-                role=_ClusterUserRoleType.USER,
-                quota=_Quota(),
-                balance=_Balance(credits=credits),
+        ) -> _OrgUserWithInfo:
+            return _OrgUserWithInfo(
                 org_name=org_name,
+                user_name=user_name,
+                role=_OrgUserRoleType.USER,
+                balance=_Balance(credits=credits),
                 user_info=_UserInfo(email=f"{user_name}@example.org"),
             )
 
@@ -232,48 +220,45 @@ def test_set_user_credits(run_cli: _RunCli) -> None:
             ("-1234.5", "-1234.50"),
             ("unlimited", "unlimited"),
         ):
-            mocked.side_effect = update_cluster_user_balance
+            mocked.side_effect = update_org_user_balance
             capture = run_cli(
                 ["admin", "set-user-credits", "default", "ivan", "--credits", value]
             )
             assert not capture.err
             assert capture.out == (
-                f"New credits for ivan on cluster default:\n"
+                f"New credits for ivan as member of org default:\n"
                 f"Credits: {outvalue}\n"
                 f"Credits spent: 0.00"
             )
             assert capture.code == 0
 
         for value in ("spam", "inf", "nan", "infinity", "Infinity"):
-            mocked.side_effect = update_cluster_user_balance
+            mocked.side_effect = update_org_user_balance
             capture = run_cli(
                 ["admin", "set-user-credits", "default", "ivan", "--credits", value]
             )
             assert f"{value} is not valid decimal number" in capture.err
             assert capture.code == 2
 
-        mocked.side_effect = update_cluster_user_balance
+        mocked.side_effect = update_org_user_balance
         capture = run_cli(["admin", "set-user-credits", "default", "ivan"])
         assert "Missing option '-c' / '--credits'." in capture.err
         assert capture.code == 2
 
 
 def test_add_user_credits(run_cli: _RunCli) -> None:
-    with mock.patch.object(_Admin, "update_cluster_user_balance_by_delta") as mocked:
+    with mock.patch.object(_Admin, "update_org_user_balance_by_delta") as mocked:
 
-        async def update_cluster_user_balance_by_delta(
-            cluster_name: str,
+        async def update_org_user_balance_by_delta(
+            org_name: str,
             user_name: str,
             delta: Decimal,
-            org_name: Optional[str] = None,
-        ) -> _ClusterUserWithInfo:
-            return _ClusterUserWithInfo(
-                cluster_name=cluster_name,
-                user_name=user_name,
-                role=_ClusterUserRoleType.USER,
-                quota=_Quota(),
-                balance=_Balance(credits=100 + delta),
+        ) -> _OrgUserWithInfo:
+            return _OrgUserWithInfo(
                 org_name=org_name,
+                user_name=user_name,
+                role=_OrgUserRoleType.USER,
+                balance=_Balance(credits=100 + delta),
                 user_info=_UserInfo(email=f"{user_name}@example.org"),
             )
 
@@ -282,27 +267,27 @@ def test_add_user_credits(run_cli: _RunCli) -> None:
             ("0", "100.00"),
             ("-1234.5", "-1134.50"),
         ):
-            mocked.side_effect = update_cluster_user_balance_by_delta
+            mocked.side_effect = update_org_user_balance_by_delta
             capture = run_cli(
                 ["admin", "add-user-credits", "default", "ivan", "--credits", value]
             )
             assert not capture.err
             assert capture.out == (
-                f"New credits for ivan on cluster default:\n"
+                f"New credits for ivan as member of org default:\n"
                 f"Credits: {outvalue}\n"
                 f"Credits spent: 0.00"
             )
             assert capture.code == 0
 
         for value in ("spam", "unlimited", "inf", "nan", "infinity", "Infinity"):
-            mocked.side_effect = update_cluster_user_balance_by_delta
+            mocked.side_effect = update_org_user_balance_by_delta
             capture = run_cli(
                 ["admin", "add-user-credits", "default", "ivan", "--credits", value]
             )
             assert f"{value} is not valid decimal number" in capture.err
             assert capture.code == 2
 
-        mocked.side_effect = update_cluster_user_balance_by_delta
+        mocked.side_effect = update_org_user_balance_by_delta
         capture = run_cli(["admin", "add-user-credits", "default", "ivan"])
         assert "Missing option '-c' / '--credits'." in capture.err
         assert capture.code == 2
@@ -380,21 +365,13 @@ def test_show_cluster_config_options(run_cli: _RunCli) -> None:
             type=_CloudProviderType.AWS,
             node_pools=[
                 _NodePoolOptions(
-                    id=" p2_xlarge",
                     machine_type="p2.xlarge",
                     cpu=4,
                     available_cpu=3,
                     memory=64 * 2**30,
                     available_memory=60 * 2**30,
-                    gpu=1,
-                    gpu_model="nvidia-tesla-k80",
-                )
-            ],
-            storages=[
-                _AWSStorageOptions(
-                    id="generalpurpose_bursting",
-                    performance_mode=_EFSPerformanceMode.GENERAL_PURPOSE,
-                    throughput_mode=_EFSThroughputMode.BURSTING,
+                    nvidia_gpu=1,
+                    nvidia_gpu_model="nvidia-tesla-k80",
                 )
             ],
         )
@@ -520,6 +497,9 @@ def test_update_resource_preset(run_cli: _RunCli) -> None:
                 nvidia_gpu=p.nvidia_gpu,
                 amd_gpu=p.amd_gpu,
                 intel_gpu=p.intel_gpu,
+                nvidia_gpu_model=p.nvidia_gpu_model,
+                amd_gpu_model=p.amd_gpu_model,
+                intel_gpu_model=p.intel_gpu_model,
                 tpu_type=p.tpu.type if p.tpu else None,
                 tpu_software_version=p.tpu.software_version if p.tpu else None,
                 preemptible_node=p.preemptible_node,
@@ -563,6 +543,12 @@ def test_update_resource_preset(run_cli: _RunCli) -> None:
                 "2",
                 "--intel-gpu",
                 "3",
+                "--nvidia-gpu-model",
+                "nvidia-tesla-k80",
+                "--amd-gpu-model",
+                "instinct-mi25",
+                "--intel-gpu-model",
+                "flex-170",
                 "--tpu-type",
                 "v2-8",
                 "--tpu-sw-version",
@@ -581,6 +567,9 @@ def test_update_resource_preset(run_cli: _RunCli) -> None:
             nvidia_gpu=1,
             amd_gpu=2,
             intel_gpu=3,
+            nvidia_gpu_model="nvidia-tesla-k80",
+            amd_gpu_model="instinct-mi25",
+            intel_gpu_model="flex-170",
             tpu_type="v2-8",
             tpu_software_version="1.14",
         )
@@ -668,11 +657,11 @@ def test_update_node_pool(run_cli: _RunCli) -> None:
         )
 
         async def update_node_pool(
-            cluster_name: str, node_pool_name: str, *, idle_size: Optional[int]
+            cluster_name: str, node_pool_name: str, request: _PatchNodePoolSizeRequest
         ) -> None:
             assert cluster_name == "default"
             assert node_pool_name == "cpu"
-            assert idle_size == 1
+            assert request.idle_size == 1
 
         clusters_mocked.side_effect = update_node_pool
 
@@ -688,3 +677,37 @@ def test_update_node_pool(run_cli: _RunCli) -> None:
         )
         assert not capture.err
         assert not capture.out
+
+
+def test_add_org_user_with_credits(run_cli: _RunCli) -> None:
+    for value in ("1234.5", "0", "-1234.5", "unlimited"):
+        with mock_create_org_user():
+            capture = run_cli(
+                [
+                    "admin",
+                    "add-org-user",
+                    "default",
+                    "ivan",
+                    "admin",
+                    "--credits",
+                    value,
+                ]
+            )
+        assert not capture.err
+        assert capture.code == 0
+
+    for value in ("spam", "inf", "nan", "infinity", "Infinity"):
+        with mock_create_cluster_user():
+            capture = run_cli(
+                [
+                    "admin",
+                    "add-org-user",
+                    "default",
+                    "ivan",
+                    "admin",
+                    "--credits",
+                    value,
+                ]
+            )
+        assert f"{value} is not valid decimal number" in capture.err, capture
+        assert capture.code == 2
